==> eiffelstudio-18.11.10.2592.tar: F_code/C4/ew153.c <==
/*
 * Code for class EW_CATALOG_IF_INST
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew153.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_CATALOG_IF_INST}.execute */
void F177_1859 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc8 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc9 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc10 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(12);
	RTLR(0,loc4);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,tr2);
	RTLR(4,loc1);
	RTLR(5,Current);
	RTLR(6,loc9);
	RTLR(7,loc5);
	RTLR(8,loc6);
	RTLR(9,loc8);
	RTLR(10,loc7);
	RTLR(11,loc10);
	RTLIU(12);
	
	RTEAA("execute", 176, Current, 10, 1, 1913);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(896, 0x00).id, 896, _OBJSIZ_1_1_0_3_0_0_0_0_);
	tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_5_);
	F895_5683(RTCW(tr1), tr2);
	loc4 = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	F894_5674(RTCW(loc4));
	RTHOOK(3);
	loc1 = F38_587(Current, loc4);
	RTHOOK(4);
	loc2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R2566[Dtype(loc1)-535])(RTCW(loc1));
	RTHOOK(5);
	if ((EIF_BOOLEAN) (loc2 < ((EIF_INTEGER_32) 1L))) {
		RTHOOK(6);
		tr1 = RTMS32_EX_H("a\000\000\000r\000\000\000g\000\000\000u\000\000\000m\000\000\000e\000\000\000n\000\000\000t\000\000\000 \000\000\000c\000\000\000o\000\000\000u\000\000\000n\000\000\000t\000\000\000 \000\000\000m\000\000\000u\000\000\000s\000\000\000t\000\000\000 \000\000\000b\000\000\000e\000\000\000 \000\000\000a\000\000\000t\000\000\000 \000\000\000l\000\000\000e\000\000\000a\000\000\000s\000\000\000t\000\000\000 \000\000\0001\000\000\000",33,1854416433);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
		RTHOOK(7);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	} else {
		RTHOOK(8);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R2857[Dtype(loc1)-575])(RTCW(loc1));
		tr2 = RTOUCR(179,F175_1838,(Current));
		tb1 = F895_5705(RTCW(tr1), tr2);
		if (tb1) {
			RTHOOK(9);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
			RTHOOK(10);
			if ((EIF_BOOLEAN) (loc2 < ((EIF_INTEGER_32) 2L))) {
				RTHOOK(11);
				tr1 = RTMS32_EX_H("a\000\000\000r\000\000\000g\000\000\000u\000\000\000m\000\000\000e\000\000\000n\000\000\000t\000\000\000 \000\000\000c\000\000\000o\000\000\000u\000\000\000n\000\000\000t\000\000\000 \000\000\000f\000\000\000o\000\000\000r\000\000\000 \000\000\000i\000\000\000n\000\000\000s\000\000\000t\000\000\000r\000\000\000u\000\000\000c\000\000\000t\000\000\000i\000\000\000o\000\000\000n\000\000\000 \000\000\000w\000\000\000i\000\000\000t\000\000\000h\000\000\000 \000\000\000\"\000\000\000",37,1137703458);
				tr2 = RTOUCR(179,F175_1838,(Current));
				tr1 = F897_5796(tr1, tr2);
				tr2 = RTMS32_EX_H("\"\000\000\000 \000\000\000m\000\000\000u\000\000\000s\000\000\000t\000\000\000 \000\000\000b\000\000\000e\000\000\000 \000\000\000a\000\000\000t\000\000\000 \000\000\000l\000\000\000e\000\000\000a\000\000\000s\000\000\000t\000\000\000 \000\000\0002\000\000\000",20,1152681266);
				tr1 = F897_5796(RTCW(tr1), tr2);
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
				RTHOOK(12);
				*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
			} else {
				RTHOOK(13);
				loc3 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
				RTHOOK(14);
				*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			}
		} else {
			RTHOOK(15);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			RTHOOK(16);
			loc3 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
			RTHOOK(17);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		}
	}
	RTHOOK(18);
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_)) {
		RTHOOK(19);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R2586[Dtype(loc1)-562])(RTCW(loc1), (EIF_REFERENCE) &loc3);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
		RTHOOK(20);
		loc9 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
		loc9 = F643_3642(RTCW(loc9), *(EIF_REFERENCE *)(Current + _REFACS_1_));
		RTHOOK(21);
		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) && (EIF_BOOLEAN)(loc9 != NULL)) || (EIF_BOOLEAN) ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) && (EIF_BOOLEAN)(loc9 == NULL)))) {
			RTHOOK(22);
			loc5 = F38_592(Current, loc4, loc3);
			RTHOOK(23);
			loc3 = F38_583(Current, loc5);
			RTHOOK(24);
			if ((EIF_BOOLEAN) (loc3 <= ((EIF_INTEGER_32) 0L))) {
				RTHOOK(25);
				loc6 = (EIF_REFERENCE) loc5;
				RTHOOK(26);
				tr1 = RTLNS(eif_new_type(896, 0x00).id, 896, _OBJSIZ_1_1_0_3_0_0_0_0_);
				F895_5681(RTCW(tr1), ((EIF_INTEGER_32) 0L));
				loc8 = (EIF_REFERENCE) tr1;
			} else {
				RTHOOK(27);
				loc6 = F897_5840(RTCW(loc5), ((EIF_INTEGER_32) 1L), (EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 1L)));
				RTHOOK(28);
				ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc5)+ _LNGOFF_1_1_0_2_);
				loc8 = F897_5840(RTCW(loc5), (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L)), ti4_1);
			}
			RTHOOK(29);
			F897_5834(RTCW(loc6));
			RTHOOK(30);
			F921_6452(RTCW(arg1), loc6);
			RTHOOK(31);
			F921_6453(RTCW(arg1), loc8);
			RTHOOK(32);
			loc7 = (EIF_REFERENCE) loc6;
			RTHOOK(33);
			tr1 = RTOUCR(96,F907_6171,(RTCW(arg1)));
			tb1 = F659_3774(RTCW(tr1), loc6);
			if ((EIF_BOOLEAN) !tb1) {
				RTHOOK(34);
				loc7 = RTOUCR(45,F175_1850,(Current));
			}
			
			RTHOOK(36);
			loc10 = RTOUCR(96,F907_6171,(RTCW(arg1)));
			loc10 = F659_3772(RTCW(loc10), loc7);
			loc10 = (EIF_REFERENCE) eif_builtin_ANY_twin (loc10);
			RTHOOK(37);
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R1450[Dtype(loc10)-155])(RTCW(loc10), arg1);
			RTHOOK(38);
			tb1 = *(EIF_BOOLEAN *)(RTCW(loc10) + O1451[Dtype(loc10)-154]);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) tb1;
			RTHOOK(39);
			tr1 = *(EIF_REFERENCE *)(RTCW(loc10));
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
		} else {
			RTHOOK(40);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		}
	}
	RTHOOK(41);
	RTLE;
	RTEE;
}

/* {EW_CATALOG_IF_INST}.variable */
EIF_REFERENCE F177_1860 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


void EIF_Minit153 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C4/ew153.c <==
/*
 * Code for class EW_CATALOG_IF_INST
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew153.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_CATALOG_IF_INST}.execute */
void F177_1859 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc8 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc9 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc10 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(12);
	RTLR(0,loc4);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,Current);
	RTLR(5,tr2);
	RTLR(6,loc9);
	RTLR(7,loc5);
	RTLR(8,loc6);
	RTLR(9,loc8);
	RTLR(10,loc7);
	RTLR(11,loc10);
	RTLIU(12);
	
	RTEAA("execute", 176, Current, 10, 1, 1913);
	RTGC;
	RTHOOK(1);
	loc4 = RTLNS(eif_new_type(896, 0x00).id, 896, _OBJSIZ_1_1_0_3_0_0_0_0_);
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_5_);
	F895_5704(RTCW(loc4), tr1);
	RTHOOK(2);
	F894_5695(RTCW(loc4));
	RTHOOK(3);
	loc1 = F38_587(Current, loc4);
	RTHOOK(4);
	loc2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R2568[Dtype(RTCW(loc1))-536])(loc1);
	RTHOOK(5);
	if ((EIF_BOOLEAN) (loc2 < ((EIF_INTEGER_32) 1L))) {
		RTHOOK(6);
		tr1 = RTMS32_EX_H("a\000\000\000r\000\000\000g\000\000\000u\000\000\000m\000\000\000e\000\000\000n\000\000\000t\000\000\000 \000\000\000c\000\000\000o\000\000\000u\000\000\000n\000\000\000t\000\000\000 \000\000\000m\000\000\000u\000\000\000s\000\000\000t\000\000\000 \000\000\000b\000\000\000e\000\000\000 \000\000\000a\000\000\000t\000\000\000 \000\000\000l\000\000\000e\000\000\000a\000\000\000s\000\000\000t\000\000\000 \000\000\0001\000\000\000",33,1854416433);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
		RTHOOK(7);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	} else {
		RTHOOK(8);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R2864[Dtype(RTCW(loc1))-625])(loc1);
		tr2 = RTOUCR(210,F175_1838, (Current));
		tb1 = F895_5726(RTCW(tr1), tr2);
		if (tb1) {
			RTHOOK(9);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
			RTHOOK(10);
			if ((EIF_BOOLEAN) (loc2 < ((EIF_INTEGER_32) 2L))) {
				RTHOOK(11);
				tr1 = RTMS32_EX_H("a\000\000\000r\000\000\000g\000\000\000u\000\000\000m\000\000\000e\000\000\000n\000\000\000t\000\000\000 \000\000\000c\000\000\000o\000\000\000u\000\000\000n\000\000\000t\000\000\000 \000\000\000f\000\000\000o\000\000\000r\000\000\000 \000\000\000i\000\000\000n\000\000\000s\000\000\000t\000\000\000r\000\000\000u\000\000\000c\000\000\000t\000\000\000i\000\000\000o\000\000\000n\000\000\000 \000\000\000w\000\000\000i\000\000\000t\000\000\000h\000\000\000 \000\000\000\"\000\000\000",37,1137703458);
				tr2 = RTOUCR(210,F175_1838, (Current));
				tr1 = F897_5817(tr1, tr2);
				tr2 = RTMS32_EX_H("\"\000\000\000 \000\000\000m\000\000\000u\000\000\000s\000\000\000t\000\000\000 \000\000\000b\000\000\000e\000\000\000 \000\000\000a\000\000\000t\000\000\000 \000\000\000l\000\000\000e\000\000\000a\000\000\000s\000\000\000t\000\000\000 \000\000\0002\000\000\000",20,1152681266);
				tr1 = F897_5817(RTCW(tr1), tr2);
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
				RTHOOK(12);
				*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
			} else {
				RTHOOK(13);
				loc3 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
				RTHOOK(14);
				*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			}
		} else {
			RTHOOK(15);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			RTHOOK(16);
			loc3 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
			RTHOOK(17);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		}
	}
	RTHOOK(18);
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_)) {
		RTHOOK(19);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R2588[Dtype(RTCW(loc1))-563])(loc1, (EIF_REFERENCE) &loc3);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
		RTHOOK(20);
		loc9 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
		loc9 = F643_3649(RTCW(loc9), *(EIF_REFERENCE *)(Current + _REFACS_1_));
		RTHOOK(21);
		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) && (EIF_BOOLEAN)(loc9 != NULL)) || (EIF_BOOLEAN) ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) && (EIF_BOOLEAN)(loc9 == NULL)))) {
			RTHOOK(22);
			loc5 = F38_592(Current, loc4, loc3);
			RTHOOK(23);
			loc3 = F38_583(Current, loc5);
			RTHOOK(24);
			if ((EIF_BOOLEAN) (loc3 <= ((EIF_INTEGER_32) 0L))) {
				RTHOOK(25);
				loc6 = (EIF_REFERENCE) loc5;
				RTHOOK(26);
				loc8 = RTLNS(eif_new_type(896, 0x00).id, 896, _OBJSIZ_1_1_0_3_0_0_0_0_);
				F895_5702(RTCW(loc8), ((EIF_INTEGER_32) 0L));
			} else {
				RTHOOK(27);
				loc6 = F897_5861(RTCW(loc5), ((EIF_INTEGER_32) 1L), (EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 1L)));
				RTHOOK(28);
				ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc5)+ _LNGOFF_1_1_0_2_);
				loc8 = F897_5861(RTCW(loc5), (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L)), ti4_1);
			}
			RTHOOK(29);
			F897_5855(RTCW(loc6));
			RTHOOK(30);
			F921_6473(RTCW(arg1), loc6);
			RTHOOK(31);
			F921_6474(RTCW(arg1), loc8);
			RTHOOK(32);
			loc7 = (EIF_REFERENCE) loc6;
			RTHOOK(33);
			tr1 = RTOUCR(96,F907_6192, (RTCW(arg1)));
			tb1 = F659_3781(RTCW(tr1), loc6);
			if ((EIF_BOOLEAN) !tb1) {
				RTHOOK(34);
				loc7 = RTOUCR(50,F175_1850, (Current));
			}
			
			RTHOOK(36);
			loc10 = RTOUCR(96,F907_6192, (RTCW(arg1)));
			loc10 = F659_3779(RTCW(loc10), loc7);
			loc10 = (EIF_REFERENCE) eif_builtin_ANY_twin (loc10);
			RTHOOK(37);
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R1450[Dtype(RTCW(loc10))-155])(loc10, arg1);
			RTHOOK(38);
			tb1 = *(EIF_BOOLEAN *)(RTCW(loc10) + O1451[Dtype(loc10)-154]);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) tb1;
			RTHOOK(39);
			tr1 = *(EIF_REFERENCE *)(RTCW(loc10));
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
		} else {
			RTHOOK(40);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		}
	}
	RTHOOK(41);
	RTLE;
	RTEE;
}

void EIF_Minit153 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
